Aperture: Also check number of focal lengths for main cameras

* Sony decided to expose back main camera as logical even though it
  technically isn't

Change-Id: I9aed662eb659f411c153548a72744c46ac6eb0bc
diff --git a/app/src/main/java/org/lineageos/aperture/utils/CameraManager.kt b/app/src/main/java/org/lineageos/aperture/utils/CameraManager.kt
index fa1ed1f..8f83e7a 100644
--- a/app/src/main/java/org/lineageos/aperture/utils/CameraManager.kt
+++ b/app/src/main/java/org/lineageos/aperture/utils/CameraManager.kt
@@ -98,8 +98,9 @@
         }
 
         val mainCamera = facingCameras.first()
-        if (mainCamera.isLogical) {
-            // If first camera is logical, it's very likely that it merges all sensors and handles
+        if (mainCamera.isLogical && mainCamera.focalLengths.size >= 2) {
+            // If first camera is logical and it has more focal lengths,
+            // it's very likely that it merges all sensors and handles
             // them with zoom (e.g. Pixels). Just expose only that
             return listOf(mainCamera)
         }